<?php

namespace Drupal\Tests\schemaapp\Unit;

use Drupal\Tests\UnitTestCase;
use function GuzzleHttp\json_decode;

/**
 * Testing for the Cache tool fetching from Schema App CDN.
 *
 * @group schemaapp
 */
class CacheTest extends UnitTestCase {

  /**
   * Test with URL Params.
   */
  public function testUsingParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com?application=drupal";

    $this->assertNotNull($url);

    $cacheService = new SchemaAppCacheService($url, $config);

    $item = $cacheService->get();

    $this->assertNotEmpty($item);

    $jsonArray = json_decode($item, TRUE);

    $this->assertEquals("Schema App URL Params", $jsonArray['name']);

  }

  /**
   * Test without url parameters.
   */
  public function testNoUrlParams() {
    $config = [
      'account_id' => 'DrupalEightTest',
      'api_key' => 'HLD5-AS53-LH74-MGO8',
      'use_url_params' => TRUE,
    ];

    $url = "http://drupal8.ugoziedge.com/node/1";

    $schemaCache = new SchemaAppCacheService($url, $config);

    $this->assertNotNull($schemaCache);
    $text = $schemaCache->get();
    $this->assertNotEmpty($text);

    $jsonArray = json_decode($text, TRUE);

    $this->assertArrayHasKey('@type', $jsonArray);

    // Ensure content is valid.
    $this->assertEquals("Schema App", $jsonArray['name']);

  }

}
